@@ -366,19 +366,21 @@ class Dataset(HDXObject):
                 ignore_fields = ['package_id']
                 resource.check_required_fields(ignore_fields=ignore_fields)
 
-    def set_updated_by_script(self, **kwargs):
+    def set_updated_by_script_batch(self, **kwargs):
         # type: (Any) -> None
-        """Set metadata field updated_by_script
+        """Set metadata fields updated_by_script, batch and batch_mode
 
         Returns:
             None
         """
         scriptinfo = kwargs.get('updated_by_script', self.configuration.get_user_agent())
-        updated_by_script = '%s (%s)' % (scriptinfo, datetime.utcnow().isoformat())
+        self.data['updated_by_script'] = '%s (%s)' % (scriptinfo, datetime.utcnow().isoformat())
         batch = kwargs.get('batch')
         if batch:
-            updated_by_script = '%s [%s]' % (updated_by_script, batch)
-        self.data['updated_by_script'] = updated_by_script
+            if not is_valid_uuid(batch):
+                raise HDXError('%s is not a valid UUID!' % batch)
+            self.data['batch'] = batch
+            self.data['batch_mode'] = 'DONT_GROUP'
 
     def _dataset_merge_hdx_update(self, update_resources, update_resources_by_name,
                                   remove_additional_resources, create_default_views, hxl_update, **kwargs):
@@ -462,7 +464,7 @@ class Dataset(HDXObject):
         if 'ignore_check' not in kwargs:  # allow ignoring of field checks
             ignore_field = self.configuration['dataset'].get('ignore_on_update')
             self.check_required_fields(ignore_fields=[ignore_field])
-        self.set_updated_by_script(**kwargs)
+        self.set_updated_by_script_batch(**kwargs)
         self._save_to_hdx('update', 'id', force_active=True)
         hdx.data.filestore_helper.FilestoreHelper.add_filestore_resources(self.data['resources'], filestore_resources)
         self.init_resources()
@@ -555,7 +557,7 @@ class Dataset(HDXObject):
                 hdx.data.filestore_helper.FilestoreHelper.check_filestore_resource(resource, ignore_fields, filestore_resources)
             self.data['resources'] = self._convert_hdxobjects(self.resources)
         self.clean_tags()
-        self.set_updated_by_script(**kwargs)
+        self.set_updated_by_script_batch(**kwargs)
         self._save_to_hdx('create', 'name', force_active=True)
         hdx.data.filestore_helper.FilestoreHelper.add_filestore_resources(self.data['resources'], filestore_resources)
         self.init_resources()
@@ -1565,7 +1567,8 @@ class Dataset(HDXObject):
                     self.preview_resourceview = None
                     break
 
-    def generate_resource_view(self, resource=0, path=None, bites_disabled=None, indicators=None):
+
+    def _generate_resource_view(self, resource=0, path=None, bites_disabled=None, indicators=None):
         # type: (Union[hdx.data.resource.Resource,Dict,str,int], Optional[str], Optional[List[bool]], Optional[List[Dict]]) -> hdx.data.resource_view.ResourceView
         """Create QuickCharts for dataset from configuration saved in resource view. You can disable specific bites
         by providing bites_disabled, a list of 3 bools where True indicates a specific bite is disabled and False
@@ -1586,6 +1589,8 @@ class Dataset(HDXObject):
         """
         if bites_disabled == [True, True, True]:
             return None
+        elif not bites_disabled:
+            bites_disabled = [False, False, False]
         res = self.set_quickchart_resource(resource)
         if res is None:
             return None
@@ -1600,39 +1605,38 @@ class Dataset(HDXObject):
             else:
                 path = script_dir_plus_file('indicator_resource_view_template.yml', NotRequestableError)
         resourceview.update_from_yaml(path=path)
-        if bites_disabled is not None or indicators is not None:
-            hxl_preview_config = resourceview['hxl_preview_config']
-            if indicators is not None:
-                len_indicators = len(indicators)
-                if len_indicators == 0:
-                    return None
-                if bites_disabled is None:
-                    bites_disabled = [True, True, True]
-                if indicators[0]:
-                    hxl_preview_config = hxl_preview_config.replace('INDICATOR_CODE_1', indicators[0]['code'])
-                    hxl_preview_config = hxl_preview_config.replace('INDICATOR_TITLE_1', indicators[0]['title'])
-                    hxl_preview_config = hxl_preview_config.replace('INDICATOR_UNIT_1', indicators[0]['unit'])
-                    bites_disabled[0] = False
-                if len_indicators > 1 and indicators[1]:
-                    hxl_preview_config = hxl_preview_config.replace('INDICATOR_CODE_2', indicators[1]['code'])
-                    hxl_preview_config = hxl_preview_config.replace('INDICATOR_TITLE_2', indicators[1]['title'])
-                    hxl_preview_config = hxl_preview_config.replace('INDICATOR_UNIT_2', indicators[1]['unit'])
-                    bites_disabled[1] = False
-                if len_indicators > 2 and indicators[2]:
-                    hxl_preview_config = hxl_preview_config.replace('INDICATOR_CODE_3', indicators[2]['code'])
-                    hxl_preview_config = hxl_preview_config.replace('INDICATOR_TITLE_3', indicators[2]['title'])
-                    hxl_preview_config = hxl_preview_config.replace('INDICATOR_UNIT_3', indicators[2]['unit'])
-                    bites_disabled[2] = False
-                if bites_disabled == [True, True, True]:
-                    return None
-            if bites_disabled:
-                hxl_preview_config = json.loads(hxl_preview_config)
-                bites = hxl_preview_config['bites']
-                for i, disable in reversed(list(enumerate(bites_disabled))):
-                    if disable:
-                        del bites[i]
-                hxl_preview_config = json.dumps(hxl_preview_config)
-            resourceview['hxl_preview_config'] = hxl_preview_config
+        hxl_preview_config = resourceview['hxl_preview_config']
+        if indicators is None:
+            indicators_notexist = [False, False, False]
+        else:
+            len_indicators = len(indicators)
+            if len_indicators == 0:
+                return None
+            indicators_notexist = [True, True, True]
+            if indicators[0]:
+                hxl_preview_config = hxl_preview_config.replace('INDICATOR_CODE_1', indicators[0]['code'])
+                hxl_preview_config = hxl_preview_config.replace('INDICATOR_TITLE_1', indicators[0]['title'])
+                hxl_preview_config = hxl_preview_config.replace('INDICATOR_UNIT_1', indicators[0]['unit'])
+                indicators_notexist[0] = False
+            if len_indicators > 1 and indicators[1]:
+                hxl_preview_config = hxl_preview_config.replace('INDICATOR_CODE_2', indicators[1]['code'])
+                hxl_preview_config = hxl_preview_config.replace('INDICATOR_TITLE_2', indicators[1]['title'])
+                hxl_preview_config = hxl_preview_config.replace('INDICATOR_UNIT_2', indicators[1]['unit'])
+                indicators_notexist[1] = False
+            if len_indicators > 2 and indicators[2]:
+                hxl_preview_config = hxl_preview_config.replace('INDICATOR_CODE_3', indicators[2]['code'])
+                hxl_preview_config = hxl_preview_config.replace('INDICATOR_TITLE_3', indicators[2]['title'])
+                hxl_preview_config = hxl_preview_config.replace('INDICATOR_UNIT_3', indicators[2]['unit'])
+                indicators_notexist[2] = False
+            if indicators_notexist == [True, True, True]:
+                return None
+        hxl_preview_config = json.loads(hxl_preview_config)
+        bites = hxl_preview_config['bites']
+        for i, disable in reversed(list(enumerate(bites_disabled))):
+            if disable or indicators_notexist[i]:
+                del bites[i]
+        hxl_preview_config = json.dumps(hxl_preview_config)
+        resourceview['hxl_preview_config'] = hxl_preview_config
 
         if 'resource_id' in resourceview:
             resourceview.create_in_hdx()
@@ -1641,6 +1645,30 @@ class Dataset(HDXObject):
             self.preview_resourceview = resourceview
         return resourceview
 
+    def generate_resource_view(self, resource=0, path=None, bites_disabled=None, indicators=None):
+        # type: (Union[hdx.data.resource.Resource,Dict,str,int], Optional[str], Optional[List[bool]], Optional[List[Dict]]) -> hdx.data.resource_view.ResourceView
+        """Create QuickCharts for dataset from configuration saved in resource view. You can disable specific bites
+        by providing bites_disabled, a list of 3 bools where True indicates a specific bite is disabled and False
+        indicates leave enabled. If you supply indicators, then the internal indicators resource view template will be
+        used. The parameter indicators is a list with 3 dictionaries of form:
+        {'code': 'MY_INDICATOR_CODE', 'title': 'MY_INDICATOR_TITLE', 'unit': 'MY_INDICATOR_UNIT'}.
+        Creation of the resource view will be delayed until after the next dataset create
+        or update if a resource id is not yet available.
+
+        Args:
+            resource (Union[hdx.data.resource.Resource,Dict,str,int]): Either resource id or name, resource metadata from a Resource object or a dictionary or position. Defaults to 0.
+            path (Optional[str]): Path to YAML resource view metadata. Defaults to None (config/hdx_resource_view_static.yml or internal template).
+            bites_disabled (Optional[List[bool]]): Which QC bites should be disabled. Defaults to None (all bites enabled).
+            indicators (Optional[List[Dict]]): Indicator codes, QC titles and units for resource view template. Defaults to None (don't use template).
+
+        Returns:
+            hdx.data.resource_view.ResourceView: The resource view if QuickCharts created, None is not
+        """
+        resourceview = self._generate_resource_view(resource, path, bites_disabled, indicators)
+        if resourceview is None:
+            self.preview_off()
+        return resourceview
+
     def get_hdx_url(self):
         # type: () -> Optional[str]
         """Get the url of the dataset on HDX
